# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from fintekkers.requests.valuation import valuation_request_pb2 as fintekkers_dot_requests_dot_valuation_dot_valuation__request__pb2
from fintekkers.requests.valuation import valuation_response_pb2 as fintekkers_dot_requests_dot_valuation_dot_valuation__response__pb2

GRPC_GENERATED_VERSION = '1.71.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in fintekkers/services/valuation_service/valuation_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ValuationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RunValuation = channel.unary_unary(
                '/fintekkers.services.valuation_service.Valuation/RunValuation',
                request_serializer=fintekkers_dot_requests_dot_valuation_dot_valuation__request__pb2.ValuationRequestProto.SerializeToString,
                response_deserializer=fintekkers_dot_requests_dot_valuation_dot_valuation__response__pb2.ValuationResponseProto.FromString,
                _registered_method=True)


class ValuationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RunValuation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ValuationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RunValuation': grpc.unary_unary_rpc_method_handler(
                    servicer.RunValuation,
                    request_deserializer=fintekkers_dot_requests_dot_valuation_dot_valuation__request__pb2.ValuationRequestProto.FromString,
                    response_serializer=fintekkers_dot_requests_dot_valuation_dot_valuation__response__pb2.ValuationResponseProto.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fintekkers.services.valuation_service.Valuation', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('fintekkers.services.valuation_service.Valuation', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Valuation(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RunValuation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/fintekkers.services.valuation_service.Valuation/RunValuation',
            fintekkers_dot_requests_dot_valuation_dot_valuation__request__pb2.ValuationRequestProto.SerializeToString,
            fintekkers_dot_requests_dot_valuation_dot_valuation__response__pb2.ValuationResponseProto.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
