# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/requests/util/operation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/requests/util/operation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(fintekkers/requests/util/operation.proto\x12\x18\x66intekkers.requests.util*a\n\x19RequestOperationTypeProto\x12\x15\n\x11UNKNOWN_OPERATION\x10\x00\x12\x0c\n\x08VALIDATE\x10\x01\x12\n\n\x06\x43REATE\x10\x02\x12\x07\n\x03GET\x10\x03\x12\n\n\x06SEARCH\x10\x04\x42\rB\tOperationP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.util.operation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\tOperationP\001'
  _globals['_REQUESTOPERATIONTYPEPROTO']._serialized_start=70
  _globals['_REQUESTOPERATIONTYPEPROTO']._serialized_end=167
# @@protoc_insertion_point(module_scope)
