# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/security/bond/auction_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/security/bond/auction_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2fintekkers/models/security/bond/auction_type.proto\x12\x1f\x66intekkers.models.security.bond*>\n\x10\x41uctionTypeProto\x12\x18\n\x14UNKNOWN_AUCTION_TYPE\x10\x00\x12\x10\n\x0cSINGLE_PRICE\x10\x01\x42\x15\x42\x11\x41uctionTypeProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.security.bond.auction_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\021AuctionTypeProtosP\001'
  _globals['_AUCTIONTYPEPROTO']._serialized_start=87
  _globals['_AUCTIONTYPEPROTO']._serialized_end=149
# @@protoc_insertion_point(module_scope)
