# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/security/security_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/security/security_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.fintekkers/models/security/security_type.proto\x12\x1a\x66intekkers.models.security*|\n\x11SecurityTypeProto\x12\x19\n\x15UNKNOWN_SECURITY_TYPE\x10\x00\x12\x11\n\rCASH_SECURITY\x10\x01\x12\x13\n\x0f\x45QUITY_SECURITY\x10\x02\x12\x11\n\rBOND_SECURITY\x10\x03\x12\x08\n\x04TIPS\x10\x04\x12\x07\n\x03\x46RN\x10\x05\x42\x16\x42\x12SecurityTypeProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.security.security_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\022SecurityTypeProtosP\001'
  _globals['_SECURITYTYPEPROTO']._serialized_start=78
  _globals['_SECURITYTYPEPROTO']._serialized_end=202
# @@protoc_insertion_point(module_scope)
