# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/security/identifier/identifier_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/models/security/identifier/identifier_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;fintekkers/models/security/identifier/identifier_type.proto\x12\x1a\x66intekkers.models.security*u\n\x13IdentifierTypeProto\x12\x1b\n\x17UNKNOWN_IDENTIFIER_TYPE\x10\x00\x12\x0f\n\x0b\x45XCH_TICKER\x10\x01\x12\x08\n\x04ISIN\x10\x02\x12\t\n\x05\x43USIP\x10\x03\x12\x07\n\x03OSI\x10\x04\x12\x08\n\x04\x46IGI\x10\x05\x12\x08\n\x04\x43\x41SH\x10\x32\x42\x18\x42\x14IdentifierTypeProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.security.identifier.identifier_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\024IdentifierTypeProtosP\001'
  _globals['_IDENTIFIERTYPEPROTO']._serialized_start=91
  _globals['_IDENTIFIERTYPEPROTO']._serialized_end=208
# @@protoc_insertion_point(module_scope)
