# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/services/position-service/position_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'fintekkers/services/position-service/position_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.requests.position import query_position_request_pb2 as fintekkers_dot_requests_dot_position_dot_query__position__request__pb2
from fintekkers.requests.position import query_position_response_pb2 as fintekkers_dot_requests_dot_position_dot_query__position__response__pb2
from fintekkers.requests.util.errors import summary_pb2 as fintekkers_dot_requests_dot_util_dot_errors_dot_summary__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;fintekkers/services/position-service/position_service.proto\x12$fintekkers.services.position_service\x1a\x39\x66intekkers/requests/position/query_position_request.proto\x1a:fintekkers/requests/position/query_position_response.proto\x1a-fintekkers/requests/util/errors/summary.proto2\x89\x02\n\x08Position\x12}\n\x06Search\x12\x37.fintekkers.requests.position.QueryPositionRequestProto\x1a\x38.fintekkers.requests.position.QueryPositionResponseProto0\x01\x12~\n\x14ValidateQueryRequest\x12\x37.fintekkers.requests.position.QueryPositionRequestProto\x1a-.fintekkers.requests.util.errors.SummaryProtoB\x06\x88\x01\x01\x90\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.services.position_service.position_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\210\001\001\220\001\001'
  _globals['_POSITION']._serialized_start=268
  _globals['_POSITION']._serialized_end=533
_builder.BuildServices(DESCRIPTOR, 'fintekkers.services.position_service.position_service_pb2', _globals)
# @@protoc_insertion_point(module_scope)
